@@ -12,7 +12,9 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
-import logging
+"""OpenStackClient plugin for Governance service."""
+
+from oslo_log import log as logging
 
 from congressclient.common import utils
 
